 Python Script to simulate The Matrix screensaver effect in a Posix Terminal
============================================================================

Just that - possibly in the future this will be made to accept coherent 
input from stdin in order to turn verbose scripts less boring.

Screenshot:

![Screenshot of terminal with Matrix running](https://raw.githubusercontent.com/jsbueno/terminal_matrix/gh-pages/screenshot.png)
